@@ -1,7 +1,7 @@
 package Sah::Schema::url;
 
 our $DATE = '2016-07-22'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 our $schema = ['str', {
     summary => 'URL string',
@@ -9,7 +9,7 @@ our $schema = ['str', {
 }, {}];
 
 1;
-# ABSTRACT:
+# ABSTRACT: URL string
 
 __END__
 
@@ -19,11 +19,11 @@ __END__
 
 =head1 NAME
 
-Sah::Schema::url
+Sah::Schema::url - URL string
 
 =head1 VERSION
 
-This document describes version 0.001 of Sah::Schema::url (from Perl distribution Sah-Schemas-URL), released on 2016-07-22.
+This document describes version 0.002 of Sah::Schema::url (from Perl distribution Sah-Schemas-URL), released on 2016-07-22.
 
 =head1 HOMEPAGE
 
