@@ -1,7 +1,7 @@
 package Sah::Schemas::URL;
 
 our $DATE = '2016-07-22'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 1;
 # ABSTRACT: Sah schemas related to URL
@@ -18,7 +18,17 @@ Sah::Schemas::URL - Sah schemas related to URL
 
 =head1 VERSION
 
-This document describes version 0.001 of Sah::Schemas::URL (from Perl distribution Sah-Schemas-URL), released on 2016-07-22.
+This document describes version 0.002 of Sah::Schemas::URL (from Perl distribution Sah-Schemas-URL), released on 2016-07-22.
+
+=head1 SAH SCHEMAS
+
+=over
+
+=item * L<url|Sah::Schema::url>
+
+URL string.
+
+=back
 
 =head1 HOMEPAGE
 
@@ -36,6 +46,12 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Sah> - specification
+
+L<Data::Sah>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
